TDPropertyValidator class

Validates event names and property payloads before they are sent to native SDK.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

validateTrack(String eventName, Map<String, dynamic> properties) TDPropertyValidationResult

Constants

maxEventNameLength → const int
maxListLength → const int
maxNestedDepth → const int
maxPropertyCount → const int
maxPropertyKeyLength → const int